@@ -10,6 +10,7 @@ from cgdb.managers import DepartmentsManager
 from cgdb.managers import ElementsCategoriesManager
 from cgdb.managers import ParametersManager
 from cgdb.managers import ElementContextsManager
+from cgdb.managers import StationGroupsManager
 
 from cgdb.utils import CGDBAPISession
 import urllib3
@@ -38,6 +39,7 @@ class CGDB:
         self._element_contexts_manager = ElementContextsManager(client=self)
         self._station_networks_manager = StationNetworksManager(client=self)
         self._aggregations_manager = AggregationsManager()
+        self._station_groups_manager = StationGroupsManager(client=self)
 
     def sites(self):
         return self._sites_manager.sites()
@@ -45,6 +47,12 @@ class CGDB:
     def site(self, mark) -> Site:
         return self._sites_manager.site(mark)
 
+    def station_groups(self):
+        return self._station_groups_manager.station_groups()
+
+    def station_group(self, mark):
+        return self._station_groups_manager.station_group(mark)
+
     def departments(self):
         return self._departments_manager.departments()
 
@@ -76,4 +84,9 @@ class CGDB:
         self._data_sets_manager.create_data_set(station, element_code, aggregation, time_step_code, data_set_type)
 
     def create_station(self, name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, remark=""):
-        self._sites_manager.create_station(name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, remark)
\ No newline at end of file
+        self._sites_manager.create_station(name, code, gpsLatitude, gpsLongitude, altitude, stationNetworkCode, remark)
+
+    def create_station_group(self, code, name, description):
+        self._station_groups_manager.create_station_group(code, name, description)
+
+    
\ No newline at end of file
