@@ -6,10 +6,10 @@ from cgdb.utils.ManagerMix import ManagerMix
 
 class SitesManager(ManagerMix):
     def __init__(self, client):
-        super(SitesManager, self).__init__(client, ["sites"])
+        super(SitesManager, self).__init__(client)
 
-    def sites(self):
-        content = self.get("sites")
+    def sites(self, url="sites"):
+        content = self.get(url)
         sites = []
 
         for station_raw in content:
